Struct ModDetail

pub struct ModDetail {
    pub brands: HashMap<String, ModDetailBrand>,
    pub issues: HashSet<ModDetailError>,
    pub item_brands: HashSet<String>,
    pub item_categories: HashSet<String>,
    pub l10n: HashMap<String, HashMap<String, String>>,
    pub placeables: HashMap<String, ModDetailPlace>,
    pub vehicles: HashMap<String, ModDetailVehicle>,
}
Mod Detail Data

Fields

brands: HashMap<String, ModDetailBrand>

list of brands

issues: HashSet<ModDetailError>

list of detected issues

item_brands: HashSet<String>

Item brands

item_categories: HashSet<String>

Item categories

l10n: HashMap<String, HashMap<String, String>>

l10n languages, keys, and strings

placeables: HashMap<String, ModDetailPlace>

placables

vehicles: HashMap<String, ModDetailVehicle>

vehicles

Implementations

Source

impl ModDetail

pub fn new() -> Self

Create new mod detail record

pub fn fast_fail(e: ModDetailError) -> Self

Create new mod detail record with a single error condition

pub fn add_issue(&mut self, issue: ModDetailError) -> &mut Self

Add an error to a mod detail record

pub fn add_lang(&mut self, language: &str, key: &str, value: &str) -> &mut Self

Add (or alter) a language code with a new key and string

pub fn add_brand( &mut self, key_name: &str, title: Option<&str>, ) -> &mut ModDetailBrand

Add a brand record

pub fn to_json_pretty(&self) -> String

Output as pretty-print JSON

pub fn to_json(&self) -> String

Output as JSON